@@ -5,13 +5,19 @@ TODO remove eval?
 
 import re
 import numpy as np
-import logging
 
 from runner.action.set.variable import Variable
 from runner.action.get.file.template import Template
 
 
 class Equation(Variable):
+    """Equation by py python code
+
+    Args:
+        pattern (str): regex expression for wildcards
+        equation (str): python code
+        route (str): route to value (see Action)
+    """
     def __init__(self, equation, pattern='\$[^\s$]*\$', route='.~~', **kwargs):
         super().__init__(**kwargs)
         self.equation = equation
